package com.ynet.life.cache;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

/* loaded from: com_ynet_life_cache.jar:com/ynet/life/cache/CacheBuilder.class */
public class CacheBuilder {
    private String resource = "com/ecc/Life/cache/cache.properties";
    private ClassLoader defaultClassLoader;

    public Map<String, CacheModel> buildCache() throws Exception {
        Properties p = getResourceAsProperties(this.resource);
        String cacheNeedSyn = p.get("cacheNeedSyn").toString();
        String synProvider = p.get("cacheClusterSynProvider").toString();
        CacheClusterSynProvider cacheClusterSynProvider = null;
        String caheStrategy = p.get("caheStrategy.default").toString();
        String cacheSize = p.get("cacheSize.default").toString();
        String cacheTime = p.get("cacheTime.default").toString();
        if (cacheNeedSyn != null && cacheNeedSyn.toLowerCase().equals("y")) {
            CacheClusterSynProvider buildCacheSyn = buildCacheSyn(synProvider);
            cacheClusterSynProvider = buildCacheSyn;
            if (buildCacheSyn instanceof SocketCacheClusterSyncProvider) {
                String clusterMember = p.get("clusterMember").toString();
                ((SocketCacheClusterSyncProvider) cacheClusterSynProvider).setClusterMember(clusterMember);
            }
        }
        int count = 1;
        Map<String, CacheConfig> tmpMap = new HashMap<>();
        while (true) {
            String cacheNamei = "cacheName.".concat(String.valueOf(count));
            Object v = p.get(cacheNamei);
            if (v != null) {
                Object caheStrategyi = p.get("caheStrategy.".concat(String.valueOf(count)));
                Object cacheSizei = p.get("cacheSize.".concat(String.valueOf(count)));
                Object cacheTimei = p.get("cacheTime.".concat(String.valueOf(count)));
                CacheConfig cc = new CacheConfig();
                cc.setCacheName(v.toString());
                cc.setCaheStrategy(caheStrategyi == null ? caheStrategy : caheStrategyi.toString());
                cc.setCacheSize(cacheSizei == null ? cacheSize : cacheSizei.toString());
                cc.setCacheTime(cacheTimei == null ? cacheTime : cacheTime.toString());
                cc.setSyProvider(cacheClusterSynProvider);
                tmpMap.put(v.toString(), cc);
                count++;
            } else {
                return buildCacheModel(tmpMap);
            }
        }
    }

    private CacheClusterSynProvider buildCacheSyn(String cacheClusterSynProvider) throws ClassNotFoundException, IllegalAccessException, InstantiationException {
        return (CacheClusterSynProvider) Class.forName(cacheClusterSynProvider).newInstance();
    }

    private Map<String, CacheModel> buildCacheModel(Map<String, CacheConfig> configMap) throws IllegalAccessException, InstantiationException, ClassNotFoundException {
        Map<String, CacheModel> cacheMap = new HashMap<>();
        for (String region : configMap.keySet()) {
            CacheConfig cc = configMap.get(region);
            CacheModel cm = new CacheModel();
            cm.configure(cc);
            cacheMap.put(region, cm);
        }
        return cacheMap;
    }

    private Properties getResourceAsProperties(String resource) throws IOException {
        Properties props = new Properties();
        InputStream in = getResourceAsStream(resource);
        props.load(in);
        in.close();
        return props;
    }

    private BufferedReader getResourceAsReader(String resource) throws IOException {
        return new BufferedReader(new InputStreamReader(getResourceAsStream(resource)));
    }

    private InputStream getResourceAsStream(String resource) throws IOException {
        return getResourceAsStream(getClassLoader(), resource);
    }

    private InputStream getResourceAsStream(ClassLoader loader, String resource) throws IOException {
        InputStream in = null;
        if (loader != null) {
            in = loader.getResourceAsStream(resource);
        }
        if (in == null) {
            in = ClassLoader.getSystemResourceAsStream(resource);
        }
        if (in == null) {
            throw new IOException("Could not find resource ".concat(String.valueOf(resource)));
        }
        return in;
    }

    private ClassLoader getClassLoader() {
        if (this.defaultClassLoader != null) {
            return this.defaultClassLoader;
        }
        return Thread.currentThread().getContextClassLoader();
    }
}
